HtechPayPaymentFieldController class
Clase controller del HtechPayCardFieldWidget, administra el widget con este controller
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAttached → bool
-
no setter
- isDisposed → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Dispose the widget: usarlo en el metodo dispose() de tu Stateful Page.
-
modeUp(
) → void - Para propositos internos. no usar!
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processPayment(
) → void - Funcion para realizar el pago con tarjeta nueva o pago con tarjeta a traves del token.
-
toString(
) → String -
A string representation of this object.
inherited
-
validateForm(
) → void - Funcion para validar los datos de la tarjeta o del cvv, la respuesta se puede obtener en el callback onValidForm
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited