ErrorsForm class

Constructors

ErrorsForm({required bool numCard, required bool date, required bool cvv})

Properties

cvv bool
getter/setter pair
date bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
numCard bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited