HtechPayCardFieldWidget class
Widget inline para realizar pagos con tarjeta nueva o con tarjetas guardadas a traves del token.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- HtechPayCardFieldWidget
Constructors
- HtechPayCardFieldWidget({Key? key, bool isSandboxMode = true, bool isDarkTheme = false, required String orderId, required HtechPayPaymentFieldController controller, required CardFieldType type, required PaymentResponse onPaymentResult, required ValidForm onValidForm, required Error onError, ProcessPayment? onProcessPayment, Challenge3dsOpen? on3dsChallengeOpen, CardFieldStatusWidget? onGetWidgetStatus, CloseConfirmCvvDialog? onClose})
-
const
Properties
- controller → HtechPayPaymentFieldController
-
Clase controller para manipular el widget
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkTheme → bool
-
Bool para indicar si el theme debe ser dark.
final
- isSandboxMode → bool
-
Marcar como false para el ambiente de produccion.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- on3dsChallengeOpen → Challenge3dsOpen?
-
Callback opcional: indica que el proceso de pago iniciara el flujo de 3ds.
final
- onClose → CloseConfirmCvvDialog?
-
Callback opcional: indica que se ha cancelado la operacion de confirmar el cvv en transacciones con pago con tarjeta token.
final
- onError → Error
-
Callback para recibir si exite un error al montar el widget.
final
- onGetWidgetStatus → CardFieldStatusWidget?
-
Callback opcional: indica el estatus del widget, cuando ha empezaro a cargarse y cuando ha finalizado de cargarse.
final
- onPaymentResult → PaymentResponse
-
Callback para recibir la respuesta del pago, si fue exitoso o no.
final
- onProcessPayment → ProcessPayment?
-
Callback opcional indica cuando el proceso de pago ha iniciado.
final
- onValidForm → ValidForm
-
Callback para recibir la respuesta de la validacion de los datos de la tarjeta.
final
- orderId → String
-
OrderId de la transaccion a cobrar.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CardFieldType
-
El tipo de widget que debe ser esta instancia, dependiendo del tipo se comportara de diferente manera.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< HtechPayCardFieldWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited